#
# spec file for package deepin-system-monitor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?is_opensuse}
    %define  distribution  openSUSE-Edition
%else
    %define  distribution  SUSE-Edition
%endif

%define    procps_version    %(rpm -q --queryformat '%%{VERSION}' procps-devel)

Name:           deepin-system-monitor
Version:        5.8.27
Release:        4.1
Summary:        A user-friendly system monitor
License:        GPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/linuxdeepin/deepin-system-monitor
Source0:        https://github.com/linuxdeepin/deepin-system-monitor/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.appdata.xml
Source2:        %{name}.svg
# PATCH-FIX-UPSTREAN fix-return-type-errors.patch hillwood@opensuse.org
Patch0:         fix-return-type-errors.patch
# PATCH-FIX-UPSTREAN fix-c++17.patch hillwood@opensuse.org - ICU 75 needs c++17
Patch1:         fix-c++17.patch
%if 0%{?suse_version} > 1500
# PATCH-FOR-OPENSUSE fix-procps-link.patch hillwood@opensuse.org - Backport support for procps 4.0
Patch2:         fix-procps-link.patch
# PATCH—FIX-OPENSUSE redefine-dmi_string.patch hillwood@opensuse.org - Fix dmi_string function error
Patch3:         redefine-dmi_string.patch
%endif
%ifarch ppc ppc64 ppc64le s390 s390x
BuildRequires:  deepin-desktop-base
%else
BuildRequires:  deepin-manual
%endif
BuildRequires:  appstream-glib
BuildRequires:  deepin-gettext-tools
BuildRequires:  desktop-file-utils
BuildRequires:  dtkcore
BuildRequires:  fdupes
BuildRequires:  gmock
BuildRequires:  gtest
BuildRequires:  hicolor-icon-theme
BuildRequires:  libcap-devel
BuildRequires:  libpcap-devel
BuildRequires:  libqt5-linguist
BuildRequires:  ncurses-devel
BuildRequires:  procps-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(dde-dock)
BuildRequires:  pkgconfig(dframeworkdbus)
BuildRequires:  pkgconfig(dtkcore) >= 5.0.0
BuildRequires:  pkgconfig(dtkgui) >= 5.0.0
BuildRequires:  pkgconfig(dtkwidget) >= 5.0.0
BuildRequires:  pkgconfig(dtkwm)
BuildRequires:  pkgconfig(gsettings-qt)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(libnl-route-3.0)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xtst)
Requires:       /usr/bin/pkexec
Requires:       hicolor-icon-theme
Requires:       qt5integration
Recommends:     %{name}-lang

%description
deepin-system-monitor is a simple process and system monitor for the Deepin
Desktop.

%lang_package

%prep
%autosetup -p1
sed -i 's/Exec=deepin-music/Exec=env QT_QPA_PLATFORMTHEME=deepin deepin-system-monitor/g' \
translations/desktop/%{name}.desktop
%if "%{procps_version}" >= "4.0.0"
sed -i '/find_library/s|procps|proc-2|' src/CMakeLists.txt
%endif

%build
%cmake -DVERSION=%{version}-%{distribution}
%make_build

%install
%cmake_install
install -Dm644 %{SOURCE1} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
install -Dm644 %{SOURCE2} %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%find_lang %{name} --with-qt
%suse_update_desktop_file -r %{name} QT System Monitor
%fdupes %{buildroot}%{_datadir}

%files
%license LICENSE COPYING
%doc README.md CHANGELOG.md
%{_bindir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_datadir}/polkit-1/actions/com.deepin.pkexec.%{name}.policy
%{_datadir}/deepin-manual/manual-assets/application/%{name}
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%files lang -f %{name}.lang
# RPM currently can not handle Asturian
%dir %{_datadir}/deepin-system-monitor
%dir %{_datadir}/deepin-system-monitor/translations
%{_datadir}/deepin-system-monitor/translations/deepin-system-monitor.qm
%lang(ast) %{_datadir}/deepin-system-monitor/translations/deepin-system-monitor_ast.qm

%changelog
* Mon Dec 16 2024 Hillwood Yang <hillwood@opensuse.org>
- Add redefine-dmi_string.patch, fix dmi_string function error.
* Thu Aug 15 2024 Hillwood Yang <hillwood@opensuse.org>
- Add fix-procps-link.patch, backport support for procps 4.0
* Fri May 31 2024 Hillwood Yang <hillwood@opensuse.org>
- Add fix-c++17.patch, icu 75 needs c++17
* Fri Oct 28 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.27
  * Fix a stuck issue
* Thu Oct 27 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Require /usr/bin/pkexec instead of pkexec (the package name):
  allow the package to install on systems where pkexec has been
  split out or not.
* Mon Jul 18 2022 Marcus Meissner <meissner@suse.com>
- require pkexec for pkexec binary
* Sun Jul  3 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.26
  * Optimize performance
  * Fix bug
  * Update translations
* Wed Apr 20 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.22
  * Fix bugs
* Thu Apr  7 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Tumbleweed
* Tue Mar 15 2022 Hillwood Yang <hillwood@opensuse.org>
- change license tag to GPL-3.0-or-later.
* Mon Feb 21 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.21
  * Optimize application
  * Fix bugs
  * Update translations
* Sat Jan 29 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.20
  * Fix bugs
  * Drop pannel icon
* Mon Nov  1 2021 Hillwood Yang <hillwood@opensuse.org>
- Update verion to 5.8.15
  * Optimize for table device
  * optimize ui
  * Drop view path feature
  * Fix bugs
  * Update translations
  * Update manual documents
  * Add the panel icon
- Add fix-return-type-errors.patch.
* Tue Jul 27 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.2
  * Optimize ui
  * Fix bugs
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.8.0.30
  * Update translations.
  * Fix: Download size in system monitor process list is greater
    than the total received data.
  * Fix: When connecting to wireless network, the network data
    cannot be monitored in the process list.
- Use find_lang macro
* Thu May  6 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.0.27
  * Update translations
  * Fix bugs
  * Support gcc 10+
  * Add user guide documents
- Enable policykit feature, fix boo#1181886
* Thu Feb  4 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.0.9
  * Use new dtk apis
  * The new ui design
- Drop deepin-system-monitor-Qt-5_15.patch, fixed by upstream
- Drop Fix-redefinition-error.patch, merged by upstream
- Don't install polkit profiles, install deepin-system-monitor-root.desktop
  instead. Workaround boo#1181886
* Thu Jun 25 2020 Hillwood Yang <hillwood@opensuse.org>
- Add deepin-system-monitor-Qt-5_15.patch
  * Support Qt 5.15
* Sat Jan 25 2020 Hillwood Yang <hillwood@opensuse.org>
- Add Fix-redefinition-error.patch.
  * Fix redefinition of 'struct std::hash<QString>' error
* Fri Sep 27 2019 Hillwood Yang <hillwood@opensuse.org>
- Update appdata.
* Thu Jul 18 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.5.2
  * Update translations
  * Add -mieee for sw_64 platform
  * Fix crash on flatpak app start
* Thu Mar  7 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.4.8.1
  * desktop: add deepin vendor
  * Fix can not find some icons.
  * Remove tooltip delay hiding.
  * Remove click focus.
  * Fix no display decimals.
  * Optimize interface.
  * HiDPI: fixed attribute dialog's icon is not clear.
  * HiDPI: fixed listview icon is not render smooth.
  * Add tray prefix in title if process is tray process.
  * Adjust network grid padding, make it in visible center of left panel.
  * Fixed arithmetic overflow error when calcuate disk read/write io.
  * Adjust curve width.
* Fri Mar 23 2018 hillwood@opensuse.org
- Update version to 1.4.3
  * Update manual.
  * Fixed display error cause by mismatch type: double -> unsigned long.
  * Add detach function to avoid segfault when exit application.
  * Change code version.
  * Init object double/float value, avoid use un-init value to draw wrong result.
    Create function 'filterInvalidNumber' to filter Inf/NaN numnber.
  * Update translations.
  * Follow DTK's API
  * Move end process dialog at center of window.
  * Add compact mode, provide multi-cpu graphics.
  * Add disk monitor graphics.
  * Fixed getcmdline crash error cause by cmdline.length() == 0
  * Fix searchbar focus problem.
  * Use default icon instead, if not found "Icon=" line in desktop file.
* Fri Dec  1 2017 hillwood@opensuse.org
- Update to 1.3.7
* Mon Nov  6 2017 hillwood@opensuse.org
- Cleanup spec
- Split language package
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
